@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import BaseModel, ConfigDict, Field, SecretStr
 
 
@@ -17,5 +15,5 @@ class QtestConfiguration(BaseModel):
         }
     )
     base_url: str = Field(description="QTest base url")
-    qtest_api_token: Optional[SecretStr] = Field(description="QTest API token", default=None)
+    qtest_api_token: SecretStr = Field(description="QTest API token")
 
