@@ -59,8 +59,6 @@ def get_tools(tools_list: list, alita_client, llm, memory_store: BaseStore = Non
                 llm=llm
             ))
         elif tool['type'] == 'memory':
-            if memory_store is None:
-                raise ToolException(f"Memory store is not provided for memory tool: {tool.get('name', tool.get('toolkit_name', 'unknown'))}")
             tools += MemoryToolkit.get_toolkit(
                 namespace=tool['settings'].get('namespace', str(tool['id'])),
                 pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
