@@ -4,6 +4,7 @@ from pydantic import create_model, BaseModel, ConfigDict, Field
 
 from .api_wrapper import SonarApiWrapper
 from ...base.tool import BaseAction
+from ...elitea_base import filter_missconfigured_index_tools
 from ...utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length
 from ....configurations.sonar import SonarConfiguration
 
@@ -43,6 +44,7 @@ class SonarToolkit(BaseToolkit):
         )
 
     @classmethod
+    @filter_missconfigured_index_tools
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
