@@ -91,12 +91,16 @@ PostmanUpdateCollectionDescription = create_model(
 
 PostmanUpdateCollectionVariables = create_model(
     "PostmanUpdateCollectionVariables",
-    variables=(List[Dict], Field(description="Updated collection variables"))
+    variables=(Optional[List[Dict[str, Any]]], Field(default=None,
+        description="List of collection variables objects. "
+                    "Example: [{'key': 'project_id', 'type': 'string', 'value': '15', 'enabled': true}]"))
 )
 
 PostmanUpdateCollectionAuth = create_model(
     "PostmanUpdateCollectionAuth",
-    auth=(Dict, Field(description="Updated authentication settings"))
+    auth=(Optional[Dict[str, Any]], Field(default=None,
+         description="Updated authentication settings. Example: {'type': 'bearer',token '': 'your_token'}"
+     ))
 )
 
 PostmanDeleteCollection = create_model(
@@ -190,19 +194,30 @@ PostmanUpdateRequestDescription = create_model(
 PostmanUpdateRequestHeaders = create_model(
     "PostmanUpdateRequestHeaders",
     request_path=(str, Field(description="Path to the request (folder/requestName)")),
-    headers=(List[Dict], Field(description="Request headers"))
+    headers=(str, Field(description="String containing HTTP headers, separated by newline characters. "
+                                    "Each header should be in the format: \"Header-Name: value\". "
+                                    "Example: \"Content-Type: application/json\\nAuthorization: Bearer token123\". "))
 )
 
 PostmanUpdateRequestBody = create_model(
     "PostmanUpdateRequestBody",
     request_path=(str, Field(description="Path to the request (folder/requestName)")),
-    body=(Dict, Field(description="Request body"))
+    body=(Optional[Dict[str, Any]], Field(default=None, description="Request body."))
 )
 
 PostmanUpdateRequestAuth = create_model(
     "PostmanUpdateRequestAuth",
     request_path=(str, Field(description="Path to the request (folder/requestName)")),
-    auth=(Dict, Field(description="Request authentication"))
+    auth=(Optional[Dict[str, Any]], Field(default=None,
+        description=(
+            "An object. "
+            "For API key authentication, use: {\"type\": \"apikey\", \"apikey\": [{\"key\": \"key\", \"value\": \"api-key\"}, {\"key\": \"value\", \"value\": \"XXX\"}]}. "
+            "For bearer authentication, use: {\"type\": \"bearer\", \"bearer\": [{\"key\": \"token\", \"value\": \"XXX\", \"type\": \"string\"}]}. "
+            "For basic authentication, use: {\"type\": \"basic\", \"basic\": [{\"key\": \"username\", \"value\": \"user\"}, {\"key\": \"password\", \"value\": \"pass\"}]}. "
+            "`type`: Authentication type (e.g., \"apikey\", \"bearer\", \"basic\"). "
+            "`apikey`, `bearer`, `basic`: List of key-value pairs for configuration."
+            "Other types can be added as needed, following the same structure."
+        )))
 )
 
 PostmanUpdateRequestTests = create_model(
@@ -692,7 +707,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
     def get_collections(self, **kwargs) -> str:
         """Get all Postman collections accessible to the user."""
         try:
-            response = self._make_request('GET', '/collections')
+            response = self._make_request('GET', f'/collections?workspace={self.workspace_id}')
             return json.dumps(response, indent=2)
         except Exception as e:
             stacktrace = format_exc()
@@ -799,11 +814,30 @@ class PostmanApiWrapper(BaseToolApiWrapper):
                     raw_body = request_body.get('raw', '')
                     body = resolve_variables(raw_body)
                     
+                    # Auto-detect JSON content and set Content-Type if not already set
+                    if not content_type and body.strip():
+                        # Try to parse as JSON to detect if it's JSON content
+                        try:
+                            # Remove JavaScript-style comments before JSON parsing
+                            import re
+                            clean_body = re.sub(r'//.*?(?=\n|$)', '', body, flags=re.MULTILINE)
+                            json.loads(clean_body)
+                            headers['Content-Type'] = 'application/json'
+                            content_type = 'application/json'
+                            # Update body to cleaned version without comments
+                            body = clean_body
+                        except json.JSONDecodeError:
+                            # Not JSON, leave as is
+                            pass
+                    
                     # Try to parse as JSON if content type suggests it
                     if 'application/json' in content_type:
                         try:
-                            # Validate JSON
-                            json.loads(body)
+                            # Remove comments and validate JSON
+                            import re
+                            clean_body = re.sub(r'//.*?(?=\n|$)', '', body, flags=re.MULTILINE)
+                            json.loads(clean_body)
+                            body = clean_body  # Use cleaned version
                         except json.JSONDecodeError:
                             logger.warning("Body is not valid JSON despite Content-Type")
                     
@@ -855,7 +889,12 @@ class PostmanApiWrapper(BaseToolApiWrapper):
                     request_kwargs['data'] = body
                 elif isinstance(body, str):
                     if 'application/json' in content_type:
-                        request_kwargs['json'] = json.loads(body) if body.strip() else {}
+                        # For JSON content, parse and use json parameter for proper handling
+                        try:
+                            request_kwargs['json'] = json.loads(body) if body.strip() else {}
+                        except json.JSONDecodeError:
+                            # Fallback to raw data if JSON parsing fails
+                            request_kwargs['data'] = body
                     else:
                         request_kwargs['data'] = body
                 else:
@@ -1214,7 +1253,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             raise ToolException(
                 f"Unable to update collection {self.collection_id} description: {str(e)}")
 
-    def update_collection_variables(self, variables: List[Dict], **kwargs) -> str:
+    def update_collection_variables(self, variables: List[Dict[str, Any]], **kwargs) -> str:
         """Update collection variables."""
         try:
             # Get current collection
@@ -1234,7 +1273,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             raise ToolException(
                 f"Unable to update collection {self.collection_id} variables: {str(e)}")
 
-    def update_collection_auth(self, auth: Dict, **kwargs) -> str:
+    def update_collection_auth(self, auth: Dict[str, Any], **kwargs) -> str:
         """Update collection authentication settings."""
         try:
             # Get current collection
@@ -1283,7 +1322,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             self.analyzer.remove_item_ids(collection_data.get("item", []))
 
             response = self._make_request(
-                'POST', '/collections', json={"collection": collection_data})
+                'POST', f'/collections?workspace={self.workspace_id}', json={"collection": collection_data})
             return json.dumps(response, indent=2)
         except Exception as e:
             stacktrace = format_exc()
@@ -1638,7 +1677,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             raise ToolException(
                 f"Unable to update request '{request_path}' description: {str(e)}")
 
-    def update_request_headers(self, request_path: str, headers: List[Dict], **kwargs) -> str:
+    def update_request_headers(self, request_path: str, headers: str, **kwargs) -> str:
         """Update request headers."""
         try:
             # Get request item and ID
@@ -1646,7 +1685,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             
             # Create update payload
             request_update = {
-                "header": headers
+                "headers": headers
             }
 
             # Update the headers field
@@ -1659,16 +1698,14 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             raise ToolException(
                 f"Unable to update request '{request_path}' headers: {str(e)}")
 
-    def update_request_body(self, request_path: str, body: Dict, **kwargs) -> str:
+    def update_request_body(self, request_path: str, body: Dict[str, Any], **kwargs) -> str:
         """Update request body."""
         try:
             # Get request item and ID
             request_item, request_id, _ = self._get_request_item_and_id(request_path)
             
             # Create update payload
-            request_update = {
-                "body": body
-            }
+            request_update = body
 
             # Update the body field
             response = self._make_request('PUT', f'/collections/{self.collection_id}/requests/{request_id}',
@@ -1680,7 +1717,7 @@ class PostmanApiWrapper(BaseToolApiWrapper):
             raise ToolException(
                 f"Unable to update request '{request_path}' body: {str(e)}")
 
-    def update_request_auth(self, request_path: str, auth: Dict, **kwargs) -> str:
+    def update_request_auth(self, request_path: str, auth: Dict[str, Any], **kwargs) -> str:
         """Update request authentication."""
         try:
             # Get request item and ID
